
[![Website](https://img.shields.io/badge/Website-Link-blue.svg)](https://gavinlyonsrepo.github.io/)  [![Rss](https://img.shields.io/badge/Subscribe-RSS-yellow.svg)](https://gavinlyonsrepo.github.io//feed.xml)  [![Donate](https://img.shields.io/badge/Donate-PayPal-green.svg)](https://www.paypal.com/paypalme/whitelight976)

![ ERM19264 LCD image ](https://github.com/gavinlyonsrepo/ERM19264_UC1609/blob/main/extras/image/color.jpg)

# ERM19264_UC1609

## Table of contents

  * [Overview](#overview)
  * [Output](#output)
  * [Installation](#installation)
  * [Hardware](#hardware)
  * [Software](#software)
	* [API](#api)
	* [SPI](#spi)
	* [Buffer](#buffer)
	* [Fonts](#fonts)
	* [Bitmaps](#bitmaps)
	* [User adjustments](#user-adjustments)
	* [Example files](#example-files)
  * [Tested MCU](#tested-mcu)
  * [Notes and Issues](#notes-and-issues)
	* [Note 1 LCD not initialising](#note-1-lcd-not-initialising)

## Overview

* Name : ERM19264_UC1609
* Title : Library for ERM19264-5 v3 LCD  (UC1609C controller) for the Arduino eco-system
* Description : 

1. Arduino eco-system library.      
2. Inverse, Scroll, rotate and contrast control. 
3. 8 ASCII fonts included.
4. Graphics class included.
5. Sleep mode.
6. Multi-screen shared buffer mode.
7. Bitmaps supported.
8. Hardware & software SPI options
9. Light weight basic text version [here at link](https://github.com/gavinlyonsrepo/ERM19264_UC1609_TEXT). 
10. Software may also work with ERM19264 LCD controlled by ST7525 controller but untested at current time.  
* Author: Gavin Lyons
* URL : [Github URL link](https://github.com/gavinlyonsrepo/ERM19264_UC1609)

## Output

Output Screenshots, From left to right top to bottom.

1. Full screen bitmap displayed
2. Multi-screen shared buffer mode, In this case screen divided into two.
3. Different size and inverted  default font 
4. ASCII font 1-127 printed out with default font size 1 
5. Fonts 7-8
6. Fonts 1-4

![output image 1](https://github.com/gavinlyonsrepo/ERM19264_UC1609/blob/main/extras/image/output.jpg)

![output image 2](https://github.com/gavinlyonsrepo/ERM19264_UC1609/blob/main/extras/image/output2.jpg)

## Installation

The library is included in the official Arduino library manger and the optimum way to install it is using the library manager which can be opened by the *manage libraries* option in Arduino IDE. 

## Hardware

9 pins , Vcc and GND, anode and cathode for the backlight LED and an SPI interface.
The example files are setup for an UNO for the pin connections used by for other MCU tested see extras folder GPIO_MCU_used.txt file. The backlight control is left up to user.
If  using Hardware SPI two of  pins will be tied to the SPI CLK and MOSI lines if using software SPI you should be able use any GPIO you want for all five pins.
Datasheet links are in the extras folder. 

There are 3 different colours in range, Parts used purchased from [ebay](https://www.ebay.ie/itm/2-inch-White-192x64-Graphic-LCD-Display-Module-UC1609-SPI-for-Arduino/293617684779?hash=item445cfa512b:g:10MAAOSwYV9e6xsi)
 
1. ERM19264SBS-5 V3 LCD Display UC1609C controller ,  white on blue
2. ERM19264FS-5 V3 LCD Display  UC1609C controller , black on white
3. ERM19264DNS-5 V3 LCD Display  UC1609C controller white on black

The library was tested on 1 and 2. 

This wiring Diagram from the manufacturer showing hardware setup connected to an ~8051 MCU, showing both 3.3 volt and 5 volt systems. 

![ ERM19264 wiring image ](https://github.com/gavinlyonsrepo/ERM19264_UC1609/blob/main/extras/image/connect.jpg)

## Software

### API 

The API (application programming interface) documentation is at link hosted on github pages and generated by Doxygen. 

[API  URL](https://gavinlyonsrepo.github.io/misc/software_docs/ERM19264_UC1609/index.html)

### SPI

Hardware and software SPI. Two different class constructors. User can pick the relevant constructor, see examples files. Hardware SPI is recommended, far faster and more reliable but Software SPI allows for more flexible GPIO selection and easier to port to other MCU' s. When running Software SPI it may be necessary on very high frequency MCU's to change the UC1609_HIGHFREQ_DELAY define, It is a microsecond delay by default it is at 0. All the hardware SPI settings are defined in the header file and can be easily changed if necessary.  It should be able to share SPI bus with other SPI devices on different SPI settings.

### Buffer

The library features a multi-screen shared buffer mode, In order to save data memory.

For example if user defines a buffer to cover the whole screen it takes 1536  bytes of data memory. Instead a user (for example) can create a buffer that covers half the screen for just 768  bytes then define two screens objects each pointing to the same buffer.
The user uses the ERM19264_UC1609_Screen Class objects to define each screen
and the ActiveBuffer pointer to switch the buffer between each screen. Multiple screens of same size can be created so LCD screen can be divided into thirds or quarters saving even more memory. The disadvantage of this is the UI/code is slightly more complicated and user can only write to one screen at a time. 

If user does not want to use multi screen mode they can simply just define ONE screen to cover entire LCD screen. See example files and API for more detail.

Figure :: The class structure with three screen object's and active buffer presently pointing to number one. 

![ ERM19264 class image ](https://github.com/gavinlyonsrepo/ERM19264_UC1609/blob/main/extras/image/screenmode.png)

### Fonts

There are eight fonts.
A print class is available to print out most passed data types.
The fonts 1-6 are a byte high(at text size 1) scale-able fonts.
Font 7-8 are specials large fonts but are numbers only and cannot be scaled(just one size).  
Font 7-8 will print just numbers + semi-colons ,  if you print a float using print method
it will place a space and use a circle for a decimal point, you can also print negative numbers with this method.  

Font data table: 

| Font num | Font enum name | Font size xbyy |  ASCII range | Size in bytes |
| ------ | ------ | ------ | ------ |  ------ | 
| 1 | UC1609Font_Default | 5x8 | ASCII 0 - 0xFF, Full Extended  | 1275 |
| 2 | UC1609Font_Thick   | 7x8 |  ASCII  0x20 - 0x5A, no lowercase letters | 406 | 
| 3 | UC1609Font_SevenSeg  | 4x8 | ASCII  0x20 - 0x7A | 360 |
| 4 | UC1609Font_Wide | 8x8 |  ASCII 0x20 - 0x5A, no lowercase letters| 464 |
| 5 | UC1609Font_Tiny | 3x8 | ASCII  0x20 - 0x7E | 285 |
| 6 | UC1609Font_Homespun  | 7x8 | ASCII  0x20 - 0x7E |  658 |
| 7 | UC1609Font_Bignum | 16x32 | ASCII 0x30-0x3A ,Numbers + : . - only | 704 |
| 8 | UC1609Font_Mednum | 16x16 | ASCII 0x30-0x3A , Numbers + : . - only | 352 |

By default only Font 1 is commented in and ready to go to save memory.
So to use a non-default Font (2-8), two steps. Comment in the respective define at top of library header file ERM19264_UC1609_graphics_font.h in the USER FONT OPTION ONE section
Call SetFontNum method and pass it name of respective font.  eg SetFontNum(UC1609Font_Wide).
The default ASCII font (font one) is an [extended ASCII font](https://www.extended-ascii.com/) 0-255 characters.
If you do not need characters 127-255 and wish to save memory space:
In library header file ERM19264_UC1609_graphics_font.cpp  in the USER FONT OPTION TWO section. Simply comment this define out.  UC_FONT_MOD_TWO (save 640 bytes).
You can also remove the first 30 characters if not needed but user will need to change 
UC1609FontOffset_Extend  from 0x00 to 0x20. This will save a further 150 bytes.

### Bitmaps

There is a few different ways of displaying bitmaps, 

| Num | Method |    Data addressing | Note |
| ------ | ------ | ------- |  ------ |  
| 1 | LCDBitmap() | Vertical |  Writes directly to screen , no buffer used. | 
| 2 | LCDBuffer()  |   Vertical  |  Mostly for internal use ... mostly | 
| 3 | buffer init technique  | Vertical  |  Can be used when initialising a buffer, splash screen | 
| 4a | drawBitmap() |   Vertical | default,  setDrawBitmapAddr(true) | 
| 4b | drawBitmap() |  Horizontal | setDrawBitmapAddr(false) |

See the bitmap example file for more details on each method. Bitmaps can be turned to data [here at link]( https://javl.github.io/image2cpp/) , Bitmaps  should be defined in the program memory and buffers in the data memory.

### User adjustments

Some users have reported the LCD not initialising correctly with this software.
It was found that by adjusting the RAM address control setting from 0x02 to 0x01.
it resolved problem.  See [ github issue 4](https://github.com/gavinlyonsrepo/ERM19264_UC1609/issues/4) for details. I suspect the root cause is different versions of product on market. As of Version 1.7.0
Users can adjust setting in the "begin" method argument list.

![ ERM19264 ram image ](https://github.com/gavinlyonsrepo/ERM19264_UC1609/blob/main/extras/image/ram.png)

When the user calls LCDbegin() to start LCD they can specify a contrast setting from 0x00 to 0xFF.
Datasheet says 0x49 is default. (VbiasPOT). Lower contrast works better on the blue version.

It is also possible for user to change LCD bias ,  Temperature coefficient, frame rate and power control but this must be done by changing defines in header file. Choose lower frame rate for lower power, and choose higher frame rate to improve LCD contrast and minimize flicker. See Data sheet for range of values
here. Defaults where found to be fine during all testing of this library.

| Parameter | default Values |  Define | Register bits |
| ------ | ------ |  ------ | ------ |
| LCD bias |  9 | BIAS_RATIO_SET | BR 1:0 |
| Temp coefficient | -0.00%/ C |  TEMP_COMP_SET | TC 1:0  |
| Frame rate | 95 fps |  FRAMERATE_SET |  LC 4:3 |
| Power control | 1.4mA + Internal VLCD (7x charge pump) |  PC_SET | PC 2:0 |
| V bias Bot(contrast) | 0x49h default|  Set by user with LCDbegin | PM 7:0 |
| Ram Address Control | 0x02 default |  Set by user with LCDbegin  | AC 2:0 |

### Example files 

| Examples files ino  | Description  | 
| ------ | ------ | 
| BITMAP | Shows use of bitmaps  | 
| GRAPHICS |  Tests use of graphics   | 
| MISC | Shows misc functions, rotate, invert etc | 
| MULTISCREEN| Shows use of multi screen mode + FPS, two screens |  
| MULTISCREEN_TWO | Shows use of multi screen mode, four screens |  
| TEXT | Shows use of text and fonts, All Fonts must be enabled to work fully  | 
| SWSPI | Shows use of software SPI | 
| HELLO | Hello world, basic use case | 

## Tested MCU

Tested on following MCUs both software and hardware SPI,
The example files are setup for an UNO for the pin connections used 
by for other MCU testing see extras/doc folder GPIO_MCU_used.txt file.

1. Arduino  UNO & NANO v3
2. ESP8266 
3. ESP32 
4. STM32 "blue pill"
5. UNO Minima R4

## Notes and Issues

